@@ -158,17 +158,17 @@
 #'                          (default) for not saving any plots, \code{"trace"}
 #'                          for saving the trace plots and \code{post} for the saving
 #'                          the posterior distribution plots.
-#' @param file              a character string indicating the \code{filename}
+#' @param filename          a character string indicating the \code{filename}
 #'                          argument (default is \code{"Blimp_Plot.pdf"}) including
 #'                          the file extension for the \code{ggsave} function.
 #'                          Note that one of \code{".eps"}, \code{".ps"},
 #'                          \code{".tex"}, \code{".pdf"} (default), \code{".jpeg"},
 #'                          \code{".tiff"}, \code{".png"}, \code{".bmp"},
 #'                          \code{".svg"} or \code{".wmf"} needs to be specified
-#'                          as file extension in the \code{file} argument.
+#'                          as file extension in the \code{filename} argument.
 #' @param file.plot         a character vector with two elements for distinguishing
 #'                          different types of plots. By default, the character
-#'                          string specified in the argument \code{"file"}
+#'                          string specified in the argument \code{"filename"}
 #'                          (\code{"Blimp_Plot"}) is concatenated with \code{"_TRACE"}
 #'                          (\code{"Blimp_Plot_TRACE"}) for the trace plots,
 #'                          and \code{"_POST"} (\code{"Blimp_Plot_POST"}) for
@@ -262,7 +262,7 @@
 #' blimp.plot("Posterior_Ex4.3", saveplot = "all")
 #'
 #' # Example 3b: Save all plots in png format with 300 dpi
-#' blimp.plot("Posterior_Ex4.3", saveplot = "all", file = "Blimp_Plot.png", dpi = 300)
+#' blimp.plot("Posterior_Ex4.3", saveplot = "all", filename = "Blimp_Plot.png", dpi = 300)
 #'
 #' # Example 3a: Save posterior distribution plot, specify width and height of the plot
 #' blimp.plot("Posterior_Ex4.3", plot = "none", saveplot = "post",
@@ -366,7 +366,7 @@ blimp.plot <- function(x, plot = c("none", "trace", "post"), param = NULL, label
                        linewidth = 0.6, linetype = "dashed", line.col = "black",
                        plot.margin = NULL, legend.title.size = 10, legend.text.size = 10,
                        legend.box.margin = NULL, saveplot = c("all", "none", "trace", "post"),
-                       file = "Blimp_Plot.pdf", file.plot = c("_TRACE", "_POST"),
+                       filename = "Blimp_Plot.pdf", file.plot = c("_TRACE", "_POST"),
                        width = NA, height = NA, units = c("in", "cm", "mm", "px"),
                        dpi = 600, check = TRUE) {
 
@@ -391,8 +391,7 @@ blimp.plot <- function(x, plot = c("none", "trace", "post"), param = NULL, label
     # Folder
     if (isTRUE(dir.exists(x))) {
 
-      x <- list.files(x, pattern = "posterior.", full.names = TRUE) |>
-             (\(z) if (isTRUE(length(z) == 0L)) { stop("There is no \"posterior\" file in the folder specified in 'x'.", call. = FALSE) } else { return(z[1L]) })()
+      x <- list.files(x, pattern = "posterior.", full.names = TRUE) |> (\(z) if (isTRUE(length(z) == 0L)) { stop("There is no \"posterior\" file in the folder specified in 'x'.", call. = FALSE) } else { return(z[1L]) })()
 
     # Data file
     } else {
@@ -432,7 +431,7 @@ blimp.plot <- function(x, plot = c("none", "trace", "post"), param = NULL, label
 
   # Check inputs
   .check.input(logical = c("labels", "burnin", "hist", "density", "area"), numeric = list(facet.nrow = 1L, facet.ncol = 1L, xlim = 2L, ylim = 2L, xexpand = 2L, yexpand = 2L, binwidth = 1L, bins = 1L, shape = 1L, linewidth = 1L, plot.margin = 4L, legend.title.size = 1L, legend.text.size = 1L, legend.box.margin = 4L, width = 1L, height = 1L, dpi = 1L),
-               character = list(xlab = 1L, ylab = 1L, file = 1L, point.col = 3L, file.plot = 2L), m.character = list(point = c("all", "none", "m", "med", "map"), saveplot = c("all", "none", "trace", "post")), s.character = list(plot = c("none", "trace", "post"), ci = c("none", "eti", "hdi"), facet.scales = c("fixed", "free", "free_x", "free_y")), args = c("alpha", "conf.level", "units"),
+               character = list(xlab = 1L, ylab = 1L, filename = 1L, point.col = 3L, file.plot = 2L), m.character = list(point = c("all", "none", "m", "med", "map"), saveplot = c("all", "none", "trace", "post")), s.character = list(plot = c("none", "trace", "post"), ci = c("none", "eti", "hdi"), facet.scales = c("fixed", "free", "free_x", "free_y")), args = c("alpha", "conf.level", "units"),
                package = "ggplot2", envir = environment(), input.check = check)
 
   # Check input 'palette'
@@ -913,7 +912,7 @@ blimp.plot <- function(x, plot = c("none", "trace", "post"), param = NULL, label
                                linewidth = linewidth, linetype = linetype, line.col = line.col,
                                plot.margin = plot.margin, legend.title.size = legend.title.size,
                                legend.text.size = legend.text.size, legend.box.margin = legend.box.margin,
-                               saveplot = saveplot, file = file, file.plot = file.plot,
+                               saveplot = saveplot, filename = filename, file.plot = file.plot,
                                width = width, height = height, units = units, dpi = dpi,
                                check = check),
                    data = list(plotdat = plotdat, trace = plotdat.trace, post = plotdat.post),
@@ -950,7 +949,7 @@ blimp.plot <- function(x, plot = c("none", "trace", "post"), param = NULL, label
   if (isTRUE(all(saveplot != "none"))) {
 
     # File extension
-    file.ext <- paste0(".", rev(unlist(strsplit(file, "\\.")))[1L])
+    file.ext <- paste0(".", rev(unlist(strsplit(filename, "\\.")))[1L])
 
     # Trace plot
     if (isTRUE("trace" %in% saveplot)) {
@@ -961,7 +960,7 @@ blimp.plot <- function(x, plot = c("none", "trace", "post"), param = NULL, label
 
       } else {
 
-        suppressWarnings(suppressMessages(ggplot2::ggsave(filename = sub(file.ext, paste0(file.plot[1L], file.ext), file), plot = object$plot$trace, width = width, height = height, units = units, dpi = dpi)))
+        suppressWarnings(suppressMessages(ggplot2::ggsave(filename = sub(file.ext, paste0(file.plot[1L], file.ext), filename), plot = object$plot$trace, width = width, height = height, units = units, dpi = dpi)))
 
       }
 
@@ -976,7 +975,7 @@ blimp.plot <- function(x, plot = c("none", "trace", "post"), param = NULL, label
 
       } else {
 
-        suppressWarnings(suppressMessages(ggplot2::ggsave(filename = sub(file.ext, paste0(file.plot[2L], file.ext), file), plot = object$plot$post, width = width, height = height, units = units, dpi = dpi)))
+        suppressWarnings(suppressMessages(ggplot2::ggsave(filename = sub(file.ext, paste0(file.plot[2L], file.ext), filename), plot = object$plot$post, width = width, height = height, units = units, dpi = dpi)))
 
       }
 
