@@ -23,7 +23,7 @@
 #'                     all variables used in the \code{model} argument.
 #' @param ...          an expression indicating the variable names in \code{data},
 #'                     e.g., \code{multilevel.invar(dat, x1, x2, x3, cluster = "cluster")}.
-#'                     Note that the operators \code{.}, \code{+}, \code{-}, \code{~},
+#'                     Note that the operators \code{+}, \code{-}, \code{~},
 #'                     \code{:}, \code{::}, and \code{!} can also be used to
 #'                     select variables, see 'Details' in the \code{\link{df.subset}}
 #'                     function.
@@ -319,18 +319,18 @@ multilevel.invar <- function(data, ..., cluster, model = NULL, rescov = NULL,
   # Data -----------------------------------------------------------------------
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data using the argument 'data' ####
+  ## Data using the argument '...' ####
 
   if (isTRUE(!missing(...))) {
 
     # Extract data
-    x <- as.data.frame(data[, .var.names(..., data = data, cluster = cluster), drop = FALSE])
+    x <- as.data.frame(data[, .var.names(data = data, ..., cluster = cluster), drop = FALSE])
 
     # Cluster variable
     cluster <- data[, cluster]
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data without using the argument 'data' ####
+  ## Data without using the argument '...' ####
 
   } else {
 
