@@ -8,7 +8,7 @@
 #'               values are coded as \code{NA}.
 #' @param ...    an expression indicating the variable names in \code{data}, e.g.,
 #'               \code{na.indicator(dat, x1, x2, x3)}. Note that the operators
-#'               \code{.}, \code{+}, \code{-}, \code{~}, \code{:}, \code{::},
+#'               \code{+}, \code{-}, \code{~}, \code{:}, \code{::},
 #'               and \code{!} can also be used to select variables, see 'Details'
 #'               in the \code{\link{df.subset}} function.
 #' @param na     an integer value specifying the value representing missing values,
@@ -35,7 +35,7 @@
 #' \code{\link{na.prop}}, \code{\link{na.test}}
 #'
 #' @references
-#' Enders, C. K. (2010). \emph{Applied missing data analysis}. Guilford Press.
+#' Enders, C. K. (2022). \emph{Applied missing data analysis} (2nd ed.). The Guilford Press.
 #'
 #' Graham, J. W. (2009). Missing data analysis: Making it work in the real world.
 #' \emph{Annual Review of Psychology, 60}, 549-576.
@@ -73,15 +73,15 @@ na.indicator <- function(data, ..., na = 1, append = TRUE, name = ".i",
   # Data -----------------------------------------------------------------------
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data using the argument 'data' ####
+  ## Data using the argument '...' ####
 
   if (isTRUE(!missing(...))) {
 
     # Extract data and convert tibble into data frame or vector
-    x <- as.data.frame(data[, .var.names(..., data = data), drop = FALSE])
+    x <- as.data.frame(data[, .var.names(data = data, ...), drop = FALSE])
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data without using the argument 'data' ####
+  ## Data without using the argument '...' ####
 
   } else {
 
