@@ -7,7 +7,7 @@
 #'                coded as \code{NA}.
 #' @param ...     an expression indicating the variable names in \code{data}, e.g.,
 #'                \code{na.prop(dat, x1, x2, x3)}. Note that the operators
-#'                \code{.}, \code{+}, \code{-}, \code{~}, \code{:}, \code{::},
+#'                \code{+}, \code{-}, \code{~}, \code{:}, \code{::},
 #'                and \code{!} can also be used to select variables, see 'Details'
 #'                in the \code{\link{df.subset}} function.
 #' @param append  logical: if \code{TRUE} (default), variable with proportion of
@@ -34,7 +34,7 @@
 #' \code{\link{na.pattern}}, \code{\link{na.test}}
 #'
 #' @references
-#' Enders, C. K. (2010). \emph{Applied missing data analysis}. Guilford Press.
+#' Enders, C. K. (2022). \emph{Applied missing data analysis} (2nd ed.). The Guilford Press.
 #'
 #' Graham, J. W. (2009). Missing data analysis: Making it work in the real world.
 #' \emph{Annual Review of Psychology, 60}, 549-576.
@@ -73,15 +73,15 @@ na.prop <- function(data, ..., digits = 2, append = TRUE, name = "na.prop",
   # Data -----------------------------------------------------------------------
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data using the argument 'data' ####
+  ## Data using the argument '...' ####
 
   if (isTRUE(!missing(...))) {
 
     # Extract data and convert tibble into data frame or vector
-    x <- as.data.frame(data[, .var.names(..., data = data), drop = FALSE])
+    x <- as.data.frame(data[, .var.names(data = data, ...), drop = FALSE])
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data without using the argument 'data' ####
+  ## Data without using the argument '...' ####
 
   } else {
 
