@@ -6,7 +6,7 @@
 #' @param data      a numeric vector, character vector, factor, or data frame.
 #' @param ...       an expression indicating the variable names in \code{data},
 #'                  e.g., \code{rec(dat, x1, x2, x3, spec = "1 = 0"))}. Note that
-#'                  the operators \code{.}, \code{+}, \code{-}, \code{~}, \code{:},
+#'                  the operators \code{+}, \code{-}, \code{~}, \code{:},
 #'                  \code{::}, and \code{!} can also be used to select variables,
 #'                  see 'Details' in the \code{\link{df.subset}} function.
 #' @param spec      a character string of recode specifications (see 'Details').
@@ -157,18 +157,18 @@ rec <- function(data, ..., spec, as.factor = FALSE, levels = NULL,
   # Data -----------------------------------------------------------------------
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data using the argument 'data' ####
+  ## Data using the argument '...' ####
 
   if (isTRUE(!missing(...))) {
 
     # Variable names
-    var.names <- .var.names(..., data = data)
+    var.names <- .var.names(data = data, ...)
 
     # Extract data and convert tibble into data frame or vector
     x <- data[, var.names] |> (\(y) if (isTRUE("tbl" %in% substr(class(y), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(y)) == 1L)) { unname(unlist(y)) } else { as.data.frame(y) } } else { y })()
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data without using the argument 'data' ####
+  ## Data without using the argument '...' ####
 
   } else {
 
